cgexplore.systems\_optimisation.FitnessCalculator
=================================================

.. currentmodule:: cgexplore.systems_optimisation

.. autoclass:: FitnessCalculator
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~FitnessCalculator.calculate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FitnessCalculator.fitness_function
      ~FitnessCalculator.chromosome_generator
      ~FitnessCalculator.structure_output
      ~FitnessCalculator.calculation_output
      ~FitnessCalculator.database_path
      ~FitnessCalculator.options
   
   